@@ -3,5 +3,6 @@ from danceschool.core.registries import ExtrasTemplateBase, extras_templates_reg
 
 @extras_templates_registry.register
 class VaccinationExtrasTemplate(ExtrasTemplateBase):
-    template = 'danceschool_dancervax/status_response.html'
+    template_name = 'danceschool_dancervax/status_response.html'
+    js_name = 'danceschool_dancervax/status_response.js'
     description = _('Vaccination status response from DancerVax')
